==> openGion_dev_5.7.5.0.zip: opengion/uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF09S.sql <==
/****************************************************************************/
/* GF09 ( ｼｰｹﾝｽ定義 )                                                       */
/*                                                                          */
/* Created : 2014/03/26 15:25:46                                            */
/****************************************************************************/
CREATE TABLE GF09 (
   SYSTEM_ID    VARCHAR ( 10 )                          NOT NULL                        /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (  1 )                          NOT NULL                        /*  20 ﾃｰﾌﾞﾙ種別    */
 , LAST_NUMBER  BIGINT                                                                  /*  22 LAST_NUMBER  */
 , SEQNAME      VARCHAR ( 50 )                          NOT NULL                        /*  30 ｼｰｹﾝｽ名      */
 , INCREBY      INTEGER             DEFAULT 1           NOT NULL                        /*  40 ｲﾝｸﾘﾒﾝﾄ      */
 , STARTVAL     INTEGER             DEFAULT 1           NOT NULL                        /*  50 開始値       */
 , MINVAL       INTEGER             DEFAULT 1           NOT NULL                        /*  60 最小値       */
 , MAXVAL       BIGINT              DEFAULT 999999999   NOT NULL                        /*  70 最大値       */
 , FGCYCLE      VARCHAR (  1 )      DEFAULT '1'         NOT NULL                        /*  80 ｻｲｸﾙﾌﾗｸﾞ     */
 , SUCACHE      INTEGER             DEFAULT 0           NOT NULL                        /*  90 ｷｬｯｼｭ数      */
 , TABLE_NAME   VARCHAR ( 50 )                                                          /* 100 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR ( 30 )                                                          /* 110 項目         */
 , UNIQ         BIGINT                                  NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (  1 )      DEFAULT '1'         NOT NULL                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR ( 14 )                                                          /* 820 登録日時     */
 , PGSET        VARCHAR ( 10 )                                                          /* 830 作成PG       */
 , PGPSET       VARCHAR ( 10 )                                                          /* 840 作成親PG     */
 , USRSET       VARCHAR ( 10 )                                                          /* 850 作成社員     */
 , DYUPD        VARCHAR ( 14 )                                                          /* 860 更新日時     */
 , PGUPD        VARCHAR ( 10 )                                                          /* 870 更新PG       */
 , PGPUPD       VARCHAR ( 10 )                                                          /* 880 更新親PG     */
 , USRUPD       VARCHAR ( 10 )                                                          /* 890 更新者       */
);

==> openGion_dev_5.7.8.0.zip: opengion/uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF09S.sql <==
/****************************************************************************/
/* GF09 ( ｼｰｹﾝｽ定義 )                                                       */
/*                                                                          */
/* Created : 2014/06/13 18:57:43                                            */
/****************************************************************************/
CREATE TABLE GF09 (
   SYSTEM_ID    VARCHAR ( 10 )                          NOT NULL                        /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (  1 )                          NOT NULL                        /*  20 ﾃｰﾌﾞﾙ種別    */
 , SEQNAME      VARCHAR ( 50 )                          NOT NULL                        /*  30 ｼｰｹﾝｽ名      */
 , INCREBY      INTEGER             DEFAULT 1           NOT NULL                        /*  40 ｲﾝｸﾘﾒﾝﾄ      */
 , STARTVAL     INTEGER             DEFAULT 1           NOT NULL                        /*  50 開始値       */
 , MINVAL       INTEGER             DEFAULT 1           NOT NULL                        /*  60 最小値       */
 , MAXVAL       INTEGER             DEFAULT 999999999   NOT NULL                        /*  70 最大値       */
 , FGCYCLE      VARCHAR (  1 )      DEFAULT '1'         NOT NULL                        /*  80 ｻｲｸﾙﾌﾗｸﾞ     */
 , SUCACHE      INTEGER             DEFAULT 0           NOT NULL                        /*  90 ｷｬｯｼｭ数      */
 , LAST_NUMBER  INTEGER                                                                 /* 100 最終値       */
 , TABLE_NAME   VARCHAR ( 50 )                                                          /* 110 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR ( 30 )                                                          /* 120 項目         */
 , UNIQ         BIGINT                                  NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (  1 )      DEFAULT '1'         NOT NULL                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR ( 14 )                                                          /* 820 登録日時     */
 , PGSET        VARCHAR ( 10 )                                                          /* 830 作成PG       */
 , PGPSET       VARCHAR ( 10 )                                                          /* 840 作成親PG     */
 , USRSET       VARCHAR ( 10 )                                                          /* 850 作成社員     */
 , DYUPD        VARCHAR ( 14 )                                                          /* 860 更新日時     */
 , PGUPD        VARCHAR ( 10 )                                                          /* 870 更新PG       */
 , PGPUPD       VARCHAR ( 10 )                                                          /* 880 更新親PG     */
 , USRUPD       VARCHAR ( 10 )                                                          /* 890 更新者       */
);
